"use strict";

// :: Header

let header = document.getElementById('header');
let navbarToggler = document.getElementById('navbarToggler');

if (header) {
    let prevScrollPosition = window.pageYOffset;

    function stickyHeader() {
        if (window.pageYOffset > 38) {
            header.classList.add("sticky");
        } else {
            header.classList.remove("sticky");
        }
    }

    window.addEventListener('load', stickyHeader);
    window.addEventListener('scroll', stickyHeader);

    navbarToggler.addEventListener('click', function () {
        header.classList.toggle("bg-white");
    });
}

function mobileDropdownMenu() {
    let sbdropdown = document.querySelectorAll('.dropdown-list').length;

    if (sbdropdown > 0) {
        let navUrl = document.querySelectorAll('.navbar-nav li ul');
        let navUrlLen = navUrl.length;

        for (let i = 0; i < navUrlLen; i++) {
            navUrl[i].insertAdjacentHTML('beforebegin', '<div class="dropdown-toggler"><i class="bi bi-chevron-down"></i></div>');
        }

        let ddtroggler = document.querySelectorAll('.dropdown-toggler');
        let ddtrogglerlen = ddtroggler.length;

        for (let i = 0; i < ddtrogglerlen; i++) {
            ddtroggler[i].addEventListener('click', function () {
                let ddNext = ddtroggler[i].nextElementSibling;
                slideToggle(ddNext, 300);
            });
        }
    }
}

window.addEventListener('load', mobileDropdownMenu);

// :: Prevent default "a" click

let anchor = document.querySelectorAll('a[href="#"]');
let anchorLength = anchor.length;

if (anchorLength > 0) {
    for (let i = 0; i < anchorLength; i++) {
        anchor[i].addEventListener('click', function (e) {
            e.preventDefault();
        });
    }
}

// :: Top Hero Card

const keyTextCard = document.querySelectorAll('.top-hero-card');

if (keyTextCard.length > 0) {
    keyTextCard.forEach((item) => {
        item.addEventListener('mouseover', () => {
            keyTextCard.forEach((s) => {
                s.classList.remove('active');
            });

            item.classList.add('active');
        });
    });
}

// :: Nice Select

let heroSelect = document.getElementById("heroSelect");

if (heroSelect) {
    NiceSelect.bind(heroSelect, {
        searchable: false
    });
}

let chatSelect = document.getElementById("chatSelect");

if (chatSelect) {
    NiceSelect.bind(chatSelect, {
        searchable: true
    });
}

let forumSelect = document.getElementById("forumSelect");

if (forumSelect) {
    NiceSelect.bind(forumSelect, {
        searchable: false
    });
}

let forgetPassSelect = document.getElementById("forgetPassSelect");

if (forgetPassSelect) {
    NiceSelect.bind(forgetPassSelect, {
        searchable: false
    });
}

// :: ChatBox

const chatboxTrigger = document.getElementById("chatboxTrigger");
const chatboxBody = document.getElementById("chatboxBody");

if (chatboxTrigger) {
    chatboxTrigger.addEventListener("click", function () {
        let userIp = localStorage.getItem('user_ip');
        $(".message-box").attr("id","message-box_"+userIp);
        $(".set-chat-box").attr("id","gust-chat-message_"+userIp);
        $(".guest-user-name").attr("id","guest-user-name_"+userIp);
        $(".guest-user-email").attr("id","guest-user-email_"+userIp);
        $(".chat-box-product").attr("id","category-box_"+userIp);
        $(".selected-product-category").attr("id","selected-product_"+userIp);
        $(".selected-guest-name").attr("id","selected-guest-name_"+userIp);
        $(".selected-guest-email").attr("id","selected-guest-email_"+userIp);
        $(".invalid-email-error").attr("id","invalid-email-error_"+userIp);
        $(".chat-box-product").addClass("category-box-"+userIp);
        $(".chat-close-btn").addClass("chat-close-btn-"+userIp);
        $(".guest-close-chat-form").attr("id","guest-close-chat-form_"+userIp);
        $(".customer-send-message").attr("id","customer-send-message_"+userIp);
        $(".agent-name").attr("id","agent-name_"+userIp);
        $(".guest-product").attr("id","guest-product_"+userIp);
        
        this.classList.toggle("active");
        chatboxBody.classList.toggle("active");
        
        $('#gust-chat-message_'+userIp).scrollTop($('#gust-chat-message_'+userIp)[0].scrollHeight);
    });
}

// :: Counter Up

let counterlen = document.querySelectorAll(".counter").length;

if (counterlen > 0) {
    let counterUp = window.counterUp.default;

    let callback = entries => {
        entries.forEach(entry => {
            let counterElement = entry.target
            if (entry.isIntersecting && !counterElement.classList.contains('is-visible')) {
                counterUp(counterElement, {
                    duration: 2000,
                    delay: 20
                });
                counterElement.classList.add('is-visible');
            }
        });
    }

    let IO = new IntersectionObserver(callback, {
        threshold: 1
    });

    let counterUpClass = document.querySelectorAll('.counter');
    let counterUpClasslen = counterUpClass.length;

    for (let i = 0; i < counterUpClasslen; i++) {
        IO.observe(counterUpClass[i]);
    }
}

// :: Scroll to Top

let scrollButton = document.getElementById('scrollToTop');
let topdistance = 600;

if (scrollButton) {
    window.addEventListener('scroll', function () {
        if (document.body.scrollTop > topdistance || document.documentElement.scrollTop > topdistance) {
            scrollButton.classList.add('scrolltop-show');
            scrollButton.classList.remove('scrolltop-hide');
        } else {
            scrollButton.classList.add('scrolltop-hide');
            scrollButton.classList.remove('scrolltop-show');
        }
    });

    scrollButton.addEventListener('click', function () {
        window.scrollTo({
            top: 0,
            left: 0,
            behavior: 'smooth'
        });
    });
}

// :: Masonry Gallery

let masonryWrapper = document.querySelectorAll('.masonary-wrapper');

if (masonryWrapper.length > 0) {
    masonryWrapper.forEach(function (container) {
        imagesLoaded(masonryWrapper, function () {
            new Isotope(container, {
                itemSelector: '.col-12',
                percentPosition: true,
                masonry: {
                    columnWidth: '.col-12'
                }
            });
        });
    });
}

// :: Tooltip

let tooltips = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
let tooltipList = tooltips.map(function (tooltipss) {
    return new bootstrap.Tooltip(tooltipss);
});

// :: Toast

let toasts = [].slice.call(document.querySelectorAll('.toast'));
let toastList = toasts.map(function (toastss) {
    return new bootstrap.Toast(toastss);
});
toastList.forEach(toast => toast.show());

// :: Popover

let popovers = [].slice.call(document.querySelectorAll('[data-bs-toggle="popover"]'))
let popoverList = popovers.map(function (popoverss) {
    return new bootstrap.Popover(popoverss);
});

// :: WOW
const WowContainer = document.querySelectorAll('.wow');

if (WowContainer.length > 0) {
    new WOW().init();
}

// :: Preloader

let preloader = document.getElementById('preloader');

if (preloader) {
    window.addEventListener('load', function () {
        let fadeOut = setInterval(function () {
            if (!preloader.style.opacity) {
                preloader.style.opacity = 1;
            }
            if (preloader.style.opacity > 0) {
                preloader.style.opacity -= 0.1;
            } else {
                clearInterval(fadeOut);
                preloader.remove();
            }
        }, 50);
    });
}